@@ -37,6 +37,7 @@ class QCalcHistory(history.AbstractHistory):
 		self._historyView = QtGui.QTreeView()
 		self._historyView.setModel(self._historyStore)
 		self._historyView.setUniformRowHeights(True)
+		self._historyView.setRootIsDecorated(False)
 		self._historyView.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
 		self._historyView.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self._historyView.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
@@ -74,6 +75,10 @@ class QCalcHistory(history.AbstractHistory):
 		equation = QtGui.QStandardItem(operation.render_operation(self._prettyRenderer, node))
 		equation.setData(node)
 		equation.setCheckable(False)
+		eqFont = equation.font()
+		eqFont.setPointSize(max(eqFont.pointSize() - 3, 5))
+		equation.setFont(eqFont)
+
 		result = QtGui.QStandardItem(operation.render_operation(self._prettyRenderer, simpleNode))
 		result.setData(simpleNode)
 		result.setEditable(False)
